/*
JRater Applet - an applet that approximates a USCF rating based on a tournament.
Copyright (C) 2012 Cory Fosmire

This file is part of the JRater Applet.

JRater is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

JRater is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with JRater.  If not, see <http://www.gnu.org/licenses/>.
*/

import java.awt.*;
import java.io.File;
import java.io.IOException;

import javax.imageio.ImageIO;
import javax.swing.*;
import javax.swing.event.*;

public class lt8Panel extends JPanel 
{

	private static final long serialVersionUID = 8845747109070544620L;
	public lt8Panel()
	{
		JLabel prelabel = new JLabel("R");
		prelabel.setToolTipText("Input current rating.");
		add(prelabel);
		
		previousfield = new JTextField("0",2);
		add(previousfield);
		previousfield.getDocument().addDocumentListener(new Elistener());
		
		JLabel w = new JLabel("W");
		w.setToolTipText("Input games won in tournament.");
		add(w);
		
		winfield = new JTextField("0",2);
		winfield.getDocument().addDocumentListener(new Elistener());
		add(winfield);
		
		JLabel loss = new JLabel("L");
		loss.setToolTipText("Input number of losses.");
		add(loss);
		
		lossfield = new JTextField("0",2);
		add(lossfield);
		lossfield.getDocument().addDocumentListener(new Elistener());
		
		JLabel avelabel = new JLabel("OA");
		avelabel.setToolTipText("Input the average of your opponent's ratings.");
		add(avelabel);
		
		averagefield = new JTextField("0",2);
		add(averagefield);
		averagefield.getDocument().addDocumentListener(new Elistener());
		
		JLabel gamelabel = new JLabel("G");
		gamelabel.setToolTipText("Input total number of USCF rated games.");
		add(gamelabel);
		
		gamesfield = new JTextField("1",2);
		add(gamesfield);
		gamesfield.getDocument().addDocumentListener(new Elistener());
		
		JLabel tlabel = new JLabel("T");
		tlabel.setToolTipText("Input # of games played in this tournament.");
		add(tlabel);
		
		tourneyfield = new JTextField("0",2);
		add(tourneyfield);
		tourneyfield.getDocument().addDocumentListener(new Elistener());
	}
	public void paint(Graphics g)
	{
		super.paint(g);
		try 
		{
			redcanoe = ImageIO.read(lt8Panel.class.getResource("red.jpg"));
		} 
		catch (IOException e) 
		{
			e.printStackTrace();
		}
		g.drawImage(redcanoe,0,50,350,350,null);
	}
	public void getE() throws NumberFormatException
	{
		try
		{
			int n = Integer.parseInt(gamesfield.getText().trim());
			int w = Integer.parseInt(winfield.getText().trim());
			int l = Integer.parseInt(lossfield.getText().trim());
			int a = Integer.parseInt(averagefield.getText().trim());
			int p = Integer.parseInt(previousfield.getText().trim());
			int t = Integer.parseInt(tourneyfield.getText().trim());
			int newrate = (n * p + t * a +(w-l)*400)/(n + t);
			String rate = "" + newrate;
			Lt8South.answer.setText(rate);
		}
		catch(NumberFormatException nf)
		{
			ErrorMessage(this, "A value could not be parsed. Error code = 01",01);
		}
		catch(ArithmeticException a)
		{
			try
			{
				ErrorMessage(this,"The sum of n and t cannot be zero. Error code = 02",02 );
				previousfield.requestFocus();
				gamesfield.setText("1");
				tourneyfield.setText("1");
			}
			catch(IllegalStateException e)
			{
				ErrorMessage(this,"Illegal State Exception generated. Error code = 00",00);
			}
		}
	}
	public void ErrorMessage(Component c, String s,int ec)
	{
		JOptionPane.showMessageDialog(c,
				s,
				"Error",
				JOptionPane.ERROR_MESSAGE);
	}
	/**
	 * A field that keeps track of games
	 */
	private JTextField gamesfield;
	/**
	 * A field that keeps track of wins
	 */
	private JTextField winfield;
	/**
	 * A field that keeps track of losses
	 */
	private JTextField lossfield;
	/**
	 * A field that keeps track of the average of your opponents
	 */
	private JTextField averagefield;
	/**
	 * A field that keeps track of your previous rating
	 */
	private JTextField previousfield;
	/**
	 * A field that keeps track of number of games played in the tournament
	 */
	private JTextField tourneyfield;
	/**
	 * A field that displays the corresponding rating
	 */
	private JTextField answer;
	private Image redcanoe;
	/**
	 * A DocumentListener for every textfield we have.
	 * @author Shamrock
	 * @return The values of E to set the answer field.
	 */
	private class Elistener implements DocumentListener
	{
		public void insertUpdate(DocumentEvent e){getE();}
		public void removeUpdate(DocumentEvent e){}
		public void changedUpdate(DocumentEvent e){getE();}
	}
	public static void main(String[]args)
	{
		JFrame test = new JFrame();
		test.setSize(500,500);
		test.add(new lt8Panel());
		test.add(new SizePanel(400,400),BorderLayout.NORTH);
		test.setVisible(true);
	}
}
